#
# spec file for package mysql-workbench
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define edition community

# whether at least Python 2.6 is available
%define have_python26   1
%include %{_rpmconfigdir}/macros.python

Summary:        A MySQL visual database modeling, administration and querying tool
License:        GPL-2.0+
Group:          Productivity/Databases/Clients
Name:           mysql-workbench
Version:        6.1.7
Release:        86.1
Url:            http://wb.mysql.com
Source:         %{name}-%{edition}-%{version}-src.tar.gz
Source1:        openSUSE_(Vendor_Package).xml

#Patches
Patch0:         patch-desktop-categories.patch
# fix deprecated calls to tpl->ReloadIfChanged
# http://bugs.mysql.com/72585
Patch1:         mysql-workbench-ctemplate.patch
# Remove check for update in help
Patch2:         mysql-workbench-no-check-for-updates.patch
# Fix build error 
# copytable.cpp:1638: undefined reference to `mysql_options4'
# This only exist in mysql 5.6.x but the if code didn't work
# So disable it
Patch3:         mysql-workbench-mysql_options4.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# Keep them alphabetic order
BuildRequires:  Mesa
BuildRequires:  Mesa-devel
BuildRequires:  Mesa-libGL-devel
BuildRequires:  ant
BuildRequires:  ant-antlr
BuildRequires:  boost-devel
BuildRequires:  cairo-devel >= 1.5.12
BuildRequires:  cairomm-devel
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  gnome-keyring-devel
BuildRequires:  gtkmm24-devel
BuildRequires:  libctemplate-devel
BuildRequires:  libglade2-devel
BuildRequires:  libgnome-devel
BuildRequires:  libiodbc-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libmysqlcppconn-devel
BuildRequires:  libmysqld-devel
BuildRequires:  libsigc++2-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  libzip-devel
BuildRequires:  vsqlite++-devel
%if 0%{?suse_version} > 1210
BuildRequires:  lua51-devel
%else
BuildRequires:  lua-devel
%endif
BuildRequires:  make
BuildRequires:  mysql-devel > 5.1
BuildRequires:  pcre-devel
BuildRequires:  python-devel
BuildRequires:  pkgconfig(libiodbc)
BuildRequires:  pkgconfig(xxf86vm)
%if 0%{?suse_version}
BuildRequires:  libuuid-devel
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
%endif
%if 0%{?fedora}
BuildRequires:  libuuid-devel
BuildRequires:  sqlite-devel
%endif
BuildRequires:  swig
BuildRequires:  tar
BuildRequires:  tinyxml-devel

Requires(post):    shared-mime-info
Requires(postun):  shared-mime-info
Requires(post):    desktop-file-utils
Requires(postun):  desktop-file-utils

Requires:       libmysqlclient-devel
Requires:       python-paramiko
Requires:       python-pexpect

# WAS in 5x Need for SQL Editor 
#Requires:       libmysqlclient_r18

## requires mysql client pkg (for mysqldump and mysql cmdline client)
Suggests:       gnome-keyring
Suggests:       mysqldump

Provides:       mysql-administrator = %{version}
Provides:       mysql-gui-tools = %{version}
Provides:       mysql-querybrovser = %{version}
Provides:       mysql-workbench-%{edition}
Obsoletes:      mysql-administrator < %{version}
Obsoletes:      mysql-gui-tools < %{version}
Obsoletes:      mysql-querybrovser < %{version}
Conflicts:      mysql-workbench-oss
Conflicts:      mysql-workbench-com-se

%description
MySQL Workbench is a modeling tool that allows you to design
and generate MySQL databases graphically. It also has administration
and query development modules where you can manage MySQL server instances
and execute SQL queries.
This is the %{edition} build.

%prep

# Add the -D flag if you don't want to delete the source root on each build
%setup -q -n %{name}-%{edition}-%{version}-src
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
# FIX this is too much on obs Out of Memory use
# %%{?_smp_mflags} could it be in _constraint ?
# make %%{?jobs:-j2}

export PATH=$PWD/bin:$PATH
# Not using cmake macro as it sets modules LDFLAGS in way that
# workbench doesn't work afterwards - more investigation needed.
%if 0
# Make things more secure, but only on new version
 export LDFLAGS="-Wl,-z,relro,-z,now -pie"
 %cmake -DMYSQL_CONFIG_PATH=%{_bindir}/mysql_config \
   -DCMAKE_BUILD_TYPE=%{edition} \
   -DREAL_EXECUTABLE_DIR=%{_libdir}/%{name} \
   -DUSE_UNIXODBC=FALSE \
   -DCMAKE_SKIP_RPATH=ON \
   -DCMAKE_SKIP_INSTALL_RPATH=ON \
   -DCMAKE_NO_BUILTIN_CHRPATH=ON \
   ..
 make VERBOSE=1 %{?jobs:-j2}
%else
 pushd build
 cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} \
   -DMYSQL_CONFIG_PATH=%{_bindir}/mysql_config \
   -DLIB_INSTALL_DIR=%{_libdir} \
   -DCMAKE_BUILD_TYPE=%{edition} \
   -DREAL_EXECUTABLE_DIR=%{_libdir}/%{name} \
   -DUSE_UNIXODBC=FALSE \
   -DCMAKE_SKIP_RPATH=ON \
   -DCMAKE_SKIP_INSTALL_RPATH=ON \
   -DCMAKE_NO_BUILTIN_CHRPATH=ON \
   ..
 make VERBOSE=1 %{?jobs:-j2}
 popd
%endif

%install
pushd build
make VERBOSE=1 DESTDIR=%{buildroot} %{?jobs:-j2} install 
popd
#Can't we split that in a -doc package ?
#rm -fr %%{buildroot}/usr/share/doc/%%{name}

find %{buildroot}%{_libdir}/%{name} -name \*.a  -exec rm {} \; -print
find %{buildroot}%{_libdir}/%{name} -name \*.la -exec rm {} \; -print

install -m 0644 "%{S:1}" %{buildroot}/usr/share/mysql-workbench/mysql.profiles

mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/%{name}" > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf
chmod 644 %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf

# workaround for prob with libantlr3c not being detected as being provided by pkg in fedora
chmod +x %{buildroot}%{_libdir}/%{name}/*.so
%fdupes -s %{buildroot}/%{_datadir}/%{name}

# Check for duplicate files
%fdupes -s %{buildroot}%{_prefix}

%post
%icon_theme_cache_post
%mime_database_post
%desktop_database_post
/sbin/ldconfig

%postun
%icon_theme_cache_postun
%mime_database_postun
%desktop_database_postun
/sbin/ldconfig

%files 
%defattr(0644, root, root, 0755)

%dir %{_datadir}/doc/mysql-workbench
%doc %{_datadir}/doc/mysql-workbench/COPYING
%doc %{_datadir}/doc/mysql-workbench/README

%attr(0755,root,root) %{_bindir}/mysql*
%attr(0755,root,root) %{_bindir}/wbcopytables
%attr(0755,root,root) %{_libdir}/%{name}/%{name}-bin

%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib*
%dir %{_libdir}/%{name}/modules
%{_libdir}/%{name}/modules/*
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/*

%dir %{_datadir}/%{name}
%{_datadir}/icons/hicolor/*/mimetypes/*
%{_datadir}/icons/hicolor/*/apps/*
%dir %{_datadir}/mime-info
%{_datadir}/mime-info/*
%{_datadir}/mime/packages/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}/*
%attr(0755,root,root) %{_datadir}/%{name}/extras/*.sh

%config(noreplace) %{_sysconfdir}/ld.so.conf.d/%{name}.conf

%changelog
* Thu Sep 11 2014 michal.hrusecky@opensuse.org
- not using %%cmake macro for now, causes too much troubles,
  needs further investigation
* Sun Sep  7 2014 michal.hrusecky@opensuse.org
- fix build by ommiting -Wl,--no-undefined
- adding -Wl,-z,relro
* Wed Jul 16 2014 ecsos@schirra.net
- insert libmysqlclient-devel for missing link
  (could not login mysqlserver)
- change lib in libdir in DLIB_INSTALL_DIR
  (workbench dont#'t start)
- comment out LDFLAGS
  (could only start as root, missing libgcc_s1)
* Sun Jul  6 2014 bruno@ioda-net.ch
- update to version 6.1.7
- Fix compilation issues on several distribution
- Added patch fixing build error inexistant mysql_option4
  mysql-workbench-mysql_options4.patch
- Added patch to remove help check for upgrade
  mysql-workbench-no-check-for-updates.patch
- Added patch to fix deprecate call ctemplate
  mysql-workbench-ctemplate.patch
  upstream bug http://bugs.mysql.com/72585
* Wed Apr 23 2014 ecsos@schirra.net
- update to version 6.1.4
* Thu Feb  6 2014 ecsos@schirra.net
- update to 6.0.9
- insert Requires: libmysqlclient-devel because of absence symlink
  of libmysqlclient_r.so
* Mon Oct  7 2013 mhrusecky@suse.cz
- updated to version 6.0.7
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-6-0-7.html
- further cleanup of spec file
* Tue Aug 20 2013 bruno@ioda-net.ch
- update to version 6.0.6
  * see http://www.mysql.com/products/workbench/
- packaging : cleaning old options, wb use cmake now
  removed no more used patches
  mysql-workbench-gpl-5.2.44-ctemplate-fix.patch
  mysql-workbench-gpl-5.2.44-avoid-version.patch
  mysql-workbench-5.2.47-system-cppconn.patch
* Wed Aug  7 2013 gankov@opensuse.org
- Add symbolic link to libmysqlclient_r
* Thu Jun  6 2013 mhrusecky@suse.com
- ugly hack around loading cppconnector manually
* Tue Jun  4 2013 mhrusecky@suse.com
- Fixed build against Factory (gtkmm/*.h -> gtkmm.h)
- Use system c++-connector:
  mysql-workbench-5.2.47-system-cppconn.patch
* Tue Mar 12 2013 speilicke@suse.com
- Fix invalid changes entry
* Wed Mar  6 2013 hpj@urpla.net
- update to version 5.2.47
  see
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-5-2-47.html
* Wed Mar  6 2013 opensuse@sukimashita.com
- update to version 5.2.46
  see
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-5-2-46.html
* Wed Jan 23 2013 gankov@opensuse.org
- update to version 5.2.45
  see
  http://dev.mysql.com/doc/relnotes/workbench/en/wb-news-5-2-45.html
* Sat Nov 24 2012 gankov@opensuse.org
- update to version 5.2.44
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-44.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-43.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-42.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-41.html
- Add build dependency on libiodbc
- rebase patches
- Don't blindly remove libs from %%{_libdir}/%%{name}/
  Some of them is runtime dependencies
* Thu Nov 15 2012 hpj@urpla.net
- build and static link included antlr3
* Wed Nov 14 2012 hpj@urpla.net
- update to version 5.2.44
- rebase patches
* Tue Sep 18 2012 idonmez@suse.com
- Add build dependency on xxf86vm to fix the build
* Sun Jun 17 2012 gankov@opensuse.org
- update to version 5.2.40
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-40.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-39.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-38.html
- add mime type support
- use fdups
- rebase patches
* Mon Mar 19 2012 bruno@ioda-net.ch
- Fix build by adding libuuid-devel
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Jan 30 2012 mhrusecky@suse.cz
- update to version 5.2.37
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-37.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-36.html
- fixed glib headers to include glib.h only
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Sep 30 2011 mhrusecky@suse.cz
- update to version 5.2.35
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-35.html
* Tue Sep 13 2011 mhrusecky@suse.cz
- fixed openSUSE configuration
* Sun Sep 11 2011 mhrusecky@suse.cz
- readded patches
- enabled command line utilities
* Mon Sep  5 2011 bruno@ioda-net.ch
- Upgraded to version 5.2.34
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-34.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-33.html
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-32.html
- removed all patches
* Thu Dec  9 2010 mhrusecky@suse.cz
- update to the version 5.2.31
  see http://dev.mysql.com/doc/workbench/en/wb-news-5-2-31.html
* Tue Nov 30 2010 mhrusecky@suse.cz
- added provides and obsoletes
* Mon Nov 29 2010 mhrusecky@suse.cz
- cleanup before submitting
* Mon Nov 22 2010 mhrusecky@suse.cz
- update to the version 5.2.30
  - recent changes
  http://dev.mysql.com/doc/workbench/en/wb-news-5-2-30.html
  - all changes:
  http://dev.mysql.com/doc/workbench/en/wb-change-history.html
* Tue Jul 27 2010 ro@suse.de
- drop glitz-devel from buildrequires (glitz backend was dropped
  from cairo two years ago)
* Wed May 19 2010 ro@suse.de
- fix build with current compiler
  (mysql-workbench-5.1.16-canvas_floater_cpp.patch)
* Tue Mar 30 2010 mhrusecky@suse.cz
- update to the version 5.2.16
  - changes:
  - http://wb.mysql.com/?p=507
* Fri Jan 29 2010 mhrusecky@suse.cz
- update to the version 5.2.15
  - changes:
  - http://wb.mysql.com/?p=482
* Thu Jan 21 2010 mhrusecky@suse.cz
- update to the version 5.2.14
  - changes:
  - http://wb.mysql.com/?p=477
* Wed Jan 20 2010 mhrusecky@suse.cz
- fixed dependencies for Fedora
* Sat Jan  9 2010 mhrusecky@suse.cz
- update to the version 5.2.11
  - changes:
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-11.html
* Sat Dec 12 2009 mhrusecky@suse.cz
- patches fixed for fuzz=0
* Wed Dec  9 2009 mhrusecky@suse.cz
- update to the version 5.2.10
  - changes:
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-9.html
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-10.html
* Mon Nov 23 2009 mhrusecky@suse.cz
- update to the version 5.2.8
  - changes:
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-7.html
  - http://dev.mysql.com/doc/workbench/en/wb-news-5-2-8.html
* Tue Nov 10 2009 mhrusecky@suse.cz
- adding configuration for openSUSE
* Tue Nov 10 2009 mhrusecky@suse.cz
- fixed .desktop file
* Mon Nov  9 2009 mhrusecky@suse.cz
- forced MySQL Workbench 5.2.6 Alpha after long and painful battle
  to compile
* Mon Oct 19 2009 mhrusecky@suse.cz
- fixed path to the libraries
* Fri Oct 16 2009 mhrusecky@suse.cz
- fixed broken link to mysqlcppconn module (bnc#547164)
* Tue Jul 28 2009 mhrusecky@suse.cz
- updating spec to search for ctemplate in ctemplate instead of google
* Tue Jul 28 2009 mhrusecky@suse.cz
- updated to version 5.1.16
  - no longer alpha version
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Tue May 19 2009 mhrusecky@suse.cz
- fixed gcc 4.4 compilation errors
* Fri May 15 2009 mhrusecky@suse.cz
- updated to the version 5.1.12 (no release notes available)
  - using new version of ctemplates correctly
  - added return statements to non-void functions
* Tue Apr 21 2009 mhrusecky@suse.cz
- updated to the version 5.1.10 (no release notes available)
* Fri Feb 20 2009 mhrusecky@suse.cz
- updated to the version 5.1.7 (no release notes available)
* Tue Jan 20 2009 mhrusecky@suse.cz
- fixed file saving (not using chdir anymore)
- added big warning about alpha version
- disable console log by default when debug isn't specified
* Tue Jan 13 2009 mhrusecky@suse.cz
- fixed paths to datadir and libdir
* Mon Jan  5 2009 mhrusecky@suse.cz
- fixed url and errors reported by rpmlint
* Tue Dec 30 2008 prusnak@suse.cz
- do not use local scintilla
- repack source so it does not contain external bundled
  (and not used) sources
- do not use strict aliasing
* Sat Dec 20 2008 mhrusecky@suse.cz
- fixed some minor errors
- using system ctemplate instead of bundled one
* Thu Dec 18 2008 mhrusecky@suse.cz
- first standalone package of mysql-workbench (Version 5.1.5)
